@@ -567,22 +567,24 @@ flagstr(int flags)
     static char bits[32];
     char *ptr;
 
+    buf[0] = '\0';
+
     if (flags == 0)
-	strcat(buf, "none");
+	pmstrncat(buf, sizeof(buf), "none");
 
     if (flags & MMV_FLAG_NOPREFIX)
-	strcat(buf, "noprefix, ");
+	pmstrncat(buf, sizeof(buf), "noprefix, ");
     if (flags & MMV_FLAG_PROCESS)
-	strcat(buf, "process, ");
+	pmstrncat(buf, sizeof(buf), "process, ");
     if (flags & MMV_FLAG_SENTINEL)
-	strcat(buf, "sentinel, ");
+	pmstrncat(buf, sizeof(buf), "sentinel, ");
 
     flags &= ~(MMV_FLAG_NOPREFIX | MMV_FLAG_PROCESS | MMV_FLAG_SENTINEL);
 
     /* unrecognised bits */
     if (flags) {
 	pmsprintf(bits, sizeof(bits), "unknown=%x", flags);
-	strcat(buf, bits);
+	pmstrncat(buf, sizeof(buf), bits);
     } else {
 	/* remove any trailing comma-space */
 	if ((ptr = strrchr(buf, ',')) != NULL)
